pub struct Repository { /* private fields */ }Implementations
Sourceimpl Repository
impl Repository
Sourcepub fn new(host: &str, owner: &str, repo: &str) -> Self
pub fn new(host: &str, owner: &str, repo: &str) -> Self
Represent a git repository in one of the git hosting providers
Sourcepub fn from_url(url: &str) -> Result<Self, Box<dyn Error>>
pub fn from_url(url: &str) -> Result<Self, Box<dyn Error>>
Extracts the owner and repository name from a URL.
Returns Repository
Where host is either “github” or “gitlab” for now.
e.g. https://github.com/szabgab/rust-digger -> (“github”, “szabgab”, “rust-digger”)
pub fn url(&self) -> String
pub fn path(&self, root: &Path) -> PathBuf
pub fn owner_path(&self, root: &Path) -> PathBuf
pub fn get_owner(&self) -> &str
pub fn is_github(&self) -> bool
pub fn is_gitlab(&self) -> bool
pub fn is_bitbucket(&self) -> bool
pub fn has_github_actions(&self, root: &Path) -> bool
pub fn has_dependabot(&self, root: &Path) -> bool
pub fn has_gitlab_pipeline(&self, root: &Path) -> bool
pub fn has_bitbucket_pipeline(&self, root: &Path) -> bool
pub fn has_circle_ci(&self, root: &Path) -> bool
pub fn has_cirrus_ci(&self, root: &Path) -> bool
pub fn has_travis(&self, root: &Path) -> bool
pub fn has_jenkins(&self, root: &Path) -> bool
pub fn has_appveyor(&self, root: &Path) -> bool
Sourcepub fn update_repository(
&self,
root: &Path,
clone: bool,
depth: Option<usize>,
) -> Result<(), Box<dyn Error>>
pub fn update_repository( &self, root: &Path, clone: bool, depth: Option<usize>, ) -> Result<(), Box<dyn Error>>
Run git clone or git pull to update a single repository
pub fn check_url(&self) -> bool